==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/testutils/src/main/java/org/apache/cxf/authservice/AuthService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.authservice;


import javax.jws.WebMethod;
import javax.jws.WebService;

/**
 *
 */

@WebService(targetNamespace = "http://cxf.apache.org/AuthService", name = "AuthService")

public interface AuthService {

    java.util.List<java.lang.String> getRoles(
                                              String sid
    );

    java.lang.String[] getRolesAsArray(String sid);

    @WebMethod(operationName = "authenticate1")
    boolean authenticate(
                         String sid,
                         String uid,
                         String pwd
    );

    //test bean mode
    @WebMethod(operationName = "authenticate2")
    boolean authenticate(Authenticate auth);

    String getAuthentication(String sid);

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/testutils/src/main/java/org/apache/cxf/authservice/AuthService.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.authservice;


import jakarta.jws.WebMethod;
import jakarta.jws.WebService;

/**
 *
 */

@WebService(targetNamespace = "http://cxf.apache.org/AuthService", name = "AuthService")

public interface AuthService {

    java.util.List<java.lang.String> getRoles(
                                              String sid
    );

    java.lang.String[] getRolesAsArray(String sid);

    @WebMethod(operationName = "authenticate1")
    boolean authenticate(
                         String sid,
                         String uid,
                         String pwd
    );

    //test bean mode
    @WebMethod(operationName = "authenticate2")
    boolean authenticate(Authenticate auth);

    String getAuthentication(String sid);

}
